<?php
namespace Ep\Cache\Adapter;

use Interop\Container\ContainerInterface;
use Symfony\Component\Cache\Adapter\ChainAdapter;
use Zend\ServiceManager\AbstractPluginManager;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Chain CacheAdaptera.
 *
 * @package Ep\Cache\Adapter
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class ChainFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return ChainAdapter
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $options = $options ?? [];

        /** @var AbstractPluginManager $plugins */
        $plugins = $container->get(PluginManager::class);

        $adapters = [];
        $maxLifetime = intval($options['max_lifetime'] ?? 0);

        foreach ($options['adapters'] ?? [] as $adapter => $options) {
            if (is_string($options)) {
                $adapters[] = $plugins->get($options);
            } else {
                $adapters[] = $plugins->get($adapter, $options);
            }
        }

        return new ChainAdapter($adapters, $maxLifetime);
    }
}