<?php
namespace Ep\Cache\Adapter;

use Ep\Cache\Exception\OptionRequiredException;
use Interop\Container\ContainerInterface;
use Symfony\Component\Cache\Adapter\RedisAdapter;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu Redis CacheAdaptera.
 *
 * @package Ep\Cache\Adapter
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class RedisFactory implements FactoryInterface
{
    /**
     * Stvara adapter.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return RedisAdapter
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     */
    public function __invoke( ContainerInterface $container, $requestedName, array $options = null )
    {
        $options = $options ?? [];

        $namespace = $options['namespace'] ?? '';
        $defaultLifetime = intval($options['default_lifetime'] ?? 0);
        $connection = $options['connection'] ?? 'redis://localhost';
        $connectionParams = $options['connection_params'] ?? [];

        if (empty($connection)) {
            throw new OptionRequiredException("Polje 'connection' je obavezno.");
        }

        $connection = RedisAdapter::createConnection($connection, $connectionParams);

        return new RedisAdapter($connection, $namespace, $defaultLifetime);
    }
}