<?php
namespace Ep\Http\Validator;

use Ep\InputFilter\Factory;
use Interop\Container\ContainerInterface;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class JsonResponseFactory
 *
 * @package Ep\Http\Validator
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class JsonResponseFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return JsonResponse
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $validator = new JsonResponse($options ?? []);

        if (isset($options['schema']) && is_array($options['schema'])) {
            $inputFilterFactory = new Factory();
            $inputFilterFactory->setInputFilterManager($container->get('InputFilterManager'));
            $inputFilterFactory->getDefaultFilterChain()->setPluginManager($container->get('FilterManager'));
            $inputFilterFactory->getDefaultValidatorChain()->setPluginManager($container->get('ValidatorManager'));

            $schema = $inputFilterFactory->createInputFilter($options['schema']);
            $validator->setInputFilter($schema);
        }

        return $validator;
    }
}