<?php
namespace Ep\Http\Validator;

use Interop\Container\ContainerInterface;
use Zend\ServiceManager\Factory\FactoryInterface;
use Zend\Validator\ValidatorInterface;
use Zend\Validator\ValidatorPluginManager;

/**
 * Stvara novu instancu ResponseValidatora.
 *
 * @package Ep\Http\Middleware
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class ValidatorChainFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return ValidatorChain
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $options = $options ?? [];

        $validatorChain = new ValidatorChain();
        $validatorChain->setPluginManager($container->get(ValidatorPluginManager::class));

        foreach ($options['validators'] ?? [] as $validator) {
            if (is_string($validator)) {
                $validatorChain->attachByName($validator);
            } elseif (is_array($validator)) {
                $validatorChain->attachByName($validator['name'], $validator['options'] ?? []);
            } elseif ($validator instanceof ValidatorInterface) {
                $validatorChain->attach($validator);
            } else {
                throw new \RuntimeException('Neispravan validator.');
            }
        }

        return $validatorChain;
    }
}