<?php
namespace Ep\InputFilter;

use Zend\InputFilter\Exception;
use Zend\InputFilter\Input;
use Zend\InputFilter\InputFilter as BaseInputFilter;

/**
 * InputFilter.
 *
 * @package Ep\InputFilter
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class InputFilter extends BaseInputFilter
{
	/** @var Factory|\Zend\InputFilter\Factory */
	protected $factory;

	/**
	 * Koristimo naš Factory.
	 *
	 * Lazy-loads a Factory instance if none attached.
	 *
	 * @return Factory
	 */
	public function getFactory(): Factory
	{
		if (null === $this->factory) {
			$this->setFactory(new Factory());
		}

		return $this->factory;
	}

	/**
	 * Ako zamijenjujemo input s imenom, zadržavamo njegov ValidatorChain.
	 *
	 * @param  mixed $input Any of the input types allowed on add() method.
	 * @param  string                              $name Name of the input to replace
	 * @return self
	 */
	public function replace($input, $name)
	{
		if (! array_key_exists($name, $this->inputs)) {
			throw new Exception\InvalidArgumentException(sprintf(
				'%s: no input found matching "%s"',
				__METHOD__,
				$name
			));
		}

		if ($input instanceof Input) {
			$old      = $this->get($name);
			$chain = $old->getValidatorChain();

			foreach ($input->getValidatorChain()->getValidators() as $validator) {
				$chain->attach($validator['instance'], $validator['breakChainOnFailure']);
			}

			$input->setValidatorChain($chain);
		}

		$this->remove($name);
		$this->add($input, $name);

		return $this;
	}
}