<?php
namespace Ep\Middleware;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Zend\Diactoros\Response\RedirectResponse;

/**
 * Ako je trenutni request zatražen putem httpa, redirektamo na https.
 *
 * @package Ep\Middleware
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class ForceHttps implements MiddlewareInterface
{
    /**
     * Ako je trenutni request zatražen putem httpa, redirektamo na https.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        $uri = $request->getUri();

        if ($uri->getScheme() !== 'https') {
            return new RedirectResponse($uri->withScheme('https'));
        }

        return $handler->handle($request);
    }
}