<?php
namespace Ep\Validator\Chain;

use Zend\Validator\ValidatorChain;

/**
 * ValidatorChain koji je aktivan ovisno o vrijednosti polja u kontekstu.
 *
 * @package Ep\Validator\Chain
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class DisableableChain extends ValidatorChain
{
	/** @var string */
	protected $fieldName;
	/** @var string */
	protected $fieldValue;

	/**
	 * DisableableValidatorChain constructor.
	 *
	 * @param array $options
	 */
	public function __construct(array $options = [])
	{
		parent::__construct();

		if (isset($options['name'])) {
			$this->fieldName = $options['name'];
		}

		if (isset($options['value'])) {
			$this->fieldValue = $options['value'];
		}
	}

	/**
	 * Ovaj validator vrši validaciju samo ako je vrijednost zadanog
	 * polja ispravne vrijednosti.
	 *
	 * @param mixed $value
	 * @param null $context
	 *
	 * @return bool
	 */
	public function isValid($value, $context = null)
	{
		$linkedValue = is_array($context) ? $context[$this->fieldName] ?? null : null;

		if (is_array($context) && $this->fieldName) {
			if (true === $this->fieldValue && !empty($linkedValue)) {
				return parent::isValid($value, $context);
			}

			if ($linkedValue === $this->fieldValue) {
				return parent::isValid($value, $context);
			}
		}

		return true;
	}
}