<?php
namespace EpTest\Config;

use Ep\Config\UniqueValueProcessor;
use PHPUnit\Framework\TestCase;

/**
 * Class UniqueValueProcessorTest
 *
 * @package EpTest\Config
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class UniqueValueProcessorTest extends TestCase
{
    public function testProcessorRemovesDuplicates()
    {
        $config = [
            'top_key' => [
                'unique_values' => [
                    'key1',
                    'key2',
                ],

                'key1' => [
                    'dupe',
                    'dupe',
                ],

                'key2' => [
                    'dupe',
                    'dupe',
                ],

                'sub_key' => [
                    'unique_values' => [
                        'key3',
                        'key4',
                    ],

                    'key3' => [
                        'dupe',
                        'dupe',
                    ],

                    'key4' => [
                        'dupe',
                        'dupe',
                    ],
                ],
            ],
        ];

        $processor = new UniqueValueProcessor();
        $processed = $processor($config);

        $this->assertCount(1, $processed['top_key']['key1']);
        $this->assertCount(1, $processed['top_key']['key2']);
        $this->assertCount(1, $processed['top_key']['sub_key']['key3']);
        $this->assertCount(1, $processed['top_key']['sub_key']['key4']);
    }

    public function testWillPreserveDuplicatesWhenKeyIsDifferent()
    {
        $config = [
            'top_key' => [
                'unique_values' => ['key1'],
                'key1' => [
                    'value1',
                    'value2' => true,
                    'value3' => true,
                ],
            ],
        ];

        $processor = new UniqueValueProcessor();
        $processed = $processor($config);

        $this->assertCount(3, $processed['top_key']['key1']);
    }

    public function testCanAcceptStringAsConfig()
    {
        $config = [
            'top_key' => [
                'unique_values' => 'key1',
                'key1' => [
                    'dupe',
                    'dupe',
                ],
            ],
        ];

        $processor = new UniqueValueProcessor();
        $processed = $processor($config);

        $this->assertCount(1, $processed['top_key']['key1']);
    }

    public function testWillNotThrowWarningForNonExistentKeys()
    {
        $config = [
            'unique_values' => 'non-existent',
        ];

        $processor = new UniqueValueProcessor();
        $processed = $processor($config);

        $this->assertEquals($config, $processed);
    }
}