<?php
namespace EpTest\Filter;

use Ep\Filter\SanitizeInput;
use PHPUnit\Framework\TestCase;

class SanitizeInputTest extends TestCase
{
    public function testFilterWorks()
    {
        $strings = [
            "Nekakav   naslov sa č i ć!!1   " => 'nekakav-naslov-sa-c-i-c1',
            "Nekakav'naslov sa č i ć   " => 'nekakavnaslov-sa-c-i-c',
            "Nekakav      naslov sa č i ć   " => 'nekakav-naslov-sa-c-i-c',
            'äöüß€' => 'aouse',
            'ÄÖÜẞ€' => 'aoube',
            '«»"' => '',
            "„„—–’" => '',
            'áéíöóőüúű   !#$%/(?' => 'aeiooouuu',
            'ùûüÿàâæçéèêëï *+÷×' => 'uuuyaaaeceeeei',
            'áčďéěíňóřšťúůýž' => 'acdeeinorstuuyz',
        ];

        $filter = new SanitizeInput();

        foreach ($strings as $raw => $filtered) {
            $this->assertEquals($filtered, $filter->filter($raw));
        }
    }

    public function testFilterWorksWhenNoSpecialCharsPresent()
    {
        $strings = [
            "RENAULT" => 'renault',
            "14 (121_)" => '14-121',
        ];

        $filter = new SanitizeInput();

        foreach ($strings as $raw => $filtered) {
            $this->assertEquals($filtered, $filter->filter($raw));
        }
    }
}