<?php
namespace EpTest\InputFilter;

use Ep\ConfigProvider;
use Ep\InputFilter\Factory;
use Ep\InputFilter\InputFilter;
use PHPUnit\Framework\TestCase;
use Zend\InputFilter\InputFilterPluginManager;
use Zend\ServiceManager\ServiceManager;
use Zend\Validator\NotEmpty;

/**
 * Testovi za InputFilter\Factory.
 *
 * @package EpTest\InputFilter
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class FactoryTest extends TestCase
{
    /**
     * Stvara čistu instancu.
     *
     * @return Factory
     */
    protected function createFactory(): Factory
    {
        $config = (new ConfigProvider())();

        $container = new ServiceManager($config['dependencies']);
        $container->setService('config', $config);

        $inputFilterManager = $container->get(InputFilterPluginManager::class);
        return new Factory($inputFilterManager);
    }

    public function testDefaultInputFilterIsInjected()
    {
        $factory = $this->createFactory();
        $inputFilter = $factory->createInputFilter([]);
        $this->assertInstanceOf(InputFilter::class, $inputFilter);
    }

    public function testCanInjectValidatorChain()
    {
        $factory = $this->createFactory();

        $input = $factory->createInput([
            'validator_chain' => Mock\ValidatorChain::class,
        ]);

        $validatorChain = $input->getValidatorChain();
        $this->assertInstanceOf(Mock\ValidatorChain::class, $validatorChain);
    }

    /**
     * @expectedException \Zend\InputFilter\Exception\RuntimeException
     */
    public function testWillThrowExceptionWhenValidatorChainIsAnArrayWithoutAName()
    {
        $factory = $this->createFactory();

        $factory->createInput([
            'validator_chain' => [],
        ]);
    }

    public function testCanCreateValidatorChainFromArray()
    {
        $factory = $this->createFactory();

        $input = $factory->createInput([
            'validator_chain' => [
                'name' => Mock\ValidatorChain::class,
                'options' => [
                    'name' => 'value',
                ],
            ],
        ]);

        /** @var Mock\ValidatorChain $validatorChain */
        $validatorChain = $input->getValidatorChain();

        $this->assertInstanceOf(Mock\ValidatorChain::class, $validatorChain);
        $this->assertEquals(['name' => 'value'], $validatorChain->options);
    }

    public function testValidatorChainWillContainValidators()
    {
        $factory = $this->createFactory();

        $input = $factory->createInput([
            'validator_chain' => Mock\ValidatorChain::class,
            'validators' => [[
                'name' => NotEmpty::class,
            ]],
        ]);

        $validatorChain = $input->getValidatorChain();
        $validators = $validatorChain->getValidators();

        $this->assertCount(1, $validators);

        $validator = $validators[0];

        $this->assertInstanceOf(NotEmpty::class, $validator['instance']);
    }
}